@@ -84,7 +84,7 @@ plugin_init (GstPlugin *plugin)
 
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
                    GST_VERSION_MINOR,
-                   "clutter",
+                   clutter,
                    "Elements to render to Clutter textures",
                    plugin_init,
                    VERSION,
